starpu_task_bundle_insert

Function starpu_task_bundle_insert 

pub unsafe extern "C" fn starpu_task_bundle_insert(
    bundle: starpu_task_bundle_t,
    task: *mut starpu_task,
) -> c_int
Insert \p task in \p bundle. Until \p task is removed from \p bundle its expected length and data transfer time will be considered along those of the other tasks of bundle. This function must not be called if \p bundle is already closed and/or \p task is already submitted. On success, it returns 0. There are two cases of error : if \p bundle is already closed it returns -EPERM, if \p task was already submitted it returns -EINVAL.