pub unsafe extern "C" fn starpu_task_set_implementation(
task: *mut starpu_task,
impl_: c_uint,
)Expand description
This function should be called by schedulers to specify the codelet implementation to be executed when executing \p task. See \ref SchedulingHelpers for more details.